change_password_route

Function change_password_route 

pub(crate) async fn change_password_route(
    __arg0: State<State>,
    __arg1: ClientIp,
    body: Args<Request>,
) -> Result<Response>
POST /_matrix/client/r0/account/password

Changes the password of this account.

  • Requires UIAA to verify user password
  • Changes the password of the sender user
  • The password hash is calculated using argon2 with 32 character salt, the plain password is not saved

If logout_devices is true it does the following for each device except the sender device:

  • Invalidates access token
  • Deletes device metadata (device id, device display name, last seen ip, last seen ts)
  • Forgets to-device events
  • Triggers device list updates