request_3pid_management_token_via_email_route

Function request_3pid_management_token_via_email_route 

pub(crate) async fn request_3pid_management_token_via_email_route(
    _body: Args<Request>,
) -> Result<Response>
POST /_matrix/client/v3/account/3pid/email/requestToken

“This API should be used to request validation tokens when adding an email address to an account”

  • 403 signals that The homeserver does not allow the third party identifier as a contact option.