fn mark_soft_failed(event: &mut CanonicalJsonObject)Expand description
Sets Synapse’s io.element.synapse.soft_failed marker inside unsigned,
creating the unsigned object when the event lacks one.
fn mark_soft_failed(event: &mut CanonicalJsonObject)Sets Synapse’s io.element.synapse.soft_failed marker inside unsigned,
creating the unsigned object when the event lacks one.