notice_power_levels

Function notice_power_levels 

fn notice_power_levels(server_user: &UserId) -> RoomPowerLevelsEventContent
Reserves posting and room administration for the server identity.

Recipients retain the ability to join and subsequently leave the room.