admin_get_room_block_route

Function admin_get_room_block_route 

pub(crate) async fn admin_get_room_block_route(
    __arg0: State<State>,
    body: Args<Request>,
) -> Result<Response>
GET /_synapse/admin/v1/rooms/{room_id}/block

Reports whether a room is blocked and, when it is, the admin that blocked it. The blocker is omitted for rooms blocked before the mxid was recorded.