resolve_boundary

Function resolve_boundary 

async fn resolve_boundary(
    services: &State,
    room_id: &RoomId,
    event_id: Option<&EventId>,
    ts: Option<MilliSecondsSinceUnixEpoch>,
) -> Result<PduCount>
Resolves the exclusive purge boundary from the boundary event or timestamp, erroring when neither is given, the event is unknown or belongs to another room, or no event precedes the timestamp.