pub(crate) async fn add_backup_keys_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
PUT /_matrix/client/r0/room_keys/keys
Add the received backup keys to the database.
- Only manipulating the most recently created version of the backup is allowed
- Adds the keys to the backup
- Returns the new number of keys in this backup and the etag