pub(crate) async fn update_device_route(
__arg0: State<State>,
__arg1: ClientIp,
body: Args<Request>,
) -> Result<Response>Expand description
PUT /_matrix/client/r0/devices/{deviceId}
Updates the metadata on a given device of the sender user, or creates the device when called by an appservice with MSC4190 enabled, returning 201 on creation and 200 on update.