merge_remote_master_key

Function merge_remote_master_key 

async fn merge_remote_master_key<F>(
    services: &Services,
    sender_user: Option<&UserId>,
    allowed_signatures: &F,
    user: &UserId,
    master_key_raw: Raw<CrossSigningKey>,
) -> Result<Raw<CrossSigningKey>>
where F: Fn(&UserId) -> bool + Send + Sync,
Merges signatures from our cached copy of the user’s master key (if any) onto the remote-supplied master key, persists the merged copy to our database, and returns the merged Raw value for the response.