banned_room_check

Function banned_room_check 

pub(crate) async fn banned_room_check(
    services: &Services,
    user_id: &UserId,
    room_id: &RoomId,
    orig_room_id: Option<&RoomOrAliasId>,
    client_ip: IpAddr,
) -> Result
Checks if the room is banned in any way possible and the sender user is not an admin.

Performs automatic deactivation if auto_deactivate_banned_room_attempts is enabled