leave_room_route

Function leave_room_route 

pub(crate) async fn leave_room_route(
    __arg0: State<State>,
    body: Args<Request>,
) -> Result<Response>
POST /_matrix/client/v3/rooms/{roomId}/leave

Tries to leave the sender user from a room.

  • This should always work if the user is currently joined.