get_avatar_url_route

Function get_avatar_url_route 

pub(crate) async fn get_avatar_url_route(
    __arg0: State<State>,
    body: Args<Request>,
) -> Result<Response>
GET /_matrix/client/v3/profile/{userId}/avatar_url

Returns the avatar_url and blurhash of the user.

  • If user is on another server and we do not have a local copy already fetch avatar_url and blurhash over federation