check_registration_token_validity

Function check_registration_token_validity 

pub(crate) async fn check_registration_token_validity(
    __arg0: State<State>,
    body: Args<Request>,
) -> Result<Response>
GET /_matrix/client/v1/register/m.login.registration_token/validity

Checks if the provided registration token is valid at the time of checking

Currently does not have any ratelimiting, and this isn’t very practical as there is only one registration token allowed.