pub(crate) async fn get_register_available_route(
__arg0: State<State>,
__arg1: ClientIp,
body: Args<Request>,
) -> Result<Response>Expand description
GET /_matrix/client/v3/register/available
Checks if a username is valid and available on this server.
Conditions for returning true:
- The user id is not historical
- The server name of the user id matches this server
- No user or appservice on this server already claimed this username
Note: This will not reserve the username, so the username might become invalid when trying to register