register_route

Function register_route 

pub(crate) async fn register_route(
    __arg0: State<State>,
    __arg1: ClientIp,
    body: Args<Request>,
) -> Result<Response>
POST /_matrix/client/v3/register

Register an account on this homeserver.

You can use [GET /_matrix/client/v3/register/available](fn.get_register_available_route. html) to check if the user id is valid and available.

  • Only works if registration is enabled
  • If type is guest: ignores all parameters except initial_device_display_name
  • If sender is not appservice: Requires UIAA (but we only use a dummy stage)
  • If type is not guest and no username is given: Always fails after UIAA check
  • Creates a new account and populates it with default account data
  • If inhibit_login is false: Creates a device and returns device id and access_token