get_room_summary_legacy

Function get_room_summary_legacy 

pub(crate) async fn get_room_summary_legacy(
    __arg0: State<State>,
    __arg1: ClientIp,
    body: Args<Request>,
) -> Result<RumaResponse<Response>>
GET /_matrix/client/unstable/im.nheko.summary/rooms/{roomIdOrAlias}/summary

Returns a short description of the state of a room.

This is the “wrong” endpoint that some implementations/clients may use according to the MSC. Request and response bodies are the same as get_room_summary.

An implementation of MSC3266