check_existing_txnid

Function check_existing_txnid 

async fn check_existing_txnid(
    services: &Services,
    sender_user: &UserId,
    sender_device: Option<&DeviceId>,
    txn_id: &TransactionId,
) -> Option<Result<Response>>
Check if this is a new transaction id. Returns Some when the transaction id exists and the send must then be terminated by returning the contained result.