send_message_event_route

Function send_message_event_route 

pub(crate) async fn send_message_event_route(
    __arg0: State<State>,
    body: Args<Request>,
) -> Result<Response>
PUT /_matrix/client/v3/rooms/{roomId}/send/{eventType}/{txnId}

Send a message event into the room.

  • Is a NOOP if the txn id was already used before and returns the same event id again
  • The only requirement for the content is that it has to be valid json
  • Tries to send the event into the room, auth rules will determine if it is allowed