get_state_events_for_empty_key_route

Function get_state_events_for_empty_key_route 

pub(crate) async fn get_state_events_for_empty_key_route(
    __arg0: State<State>,
    body: Args<Request>,
) -> Result<RumaResponse<Response>>
GET /_matrix/client/v3/rooms/{roomid}/state/{eventType}

Get single state event of a room. The optional query parameter ?format=event|content allows returning the full room state event or just the state event’s content (default behaviour)

  • If not joined: Only works if current room history visibility is world readable