witnessed

Function witnessed 

async fn witnessed(
    services: &Services,
    sender_user: &UserId,
    initial: bool,
    rooms: &Rooms,
    filter: &FilterDefinition,
    changes: Candidates,
) -> Result<Candidates>
Adds current bases for the initial scope and members this response names.

Non-lazy initial bases use current joined membership independently of event filtering. Lazy and incremental responses also introduce the subjects their member events name, while self gets an initial base even without rooms.