sync_events_v5_route

Function sync_events_v5_route 

pub(crate) async fn sync_events_v5_route(
    __arg0: Extension<Arc<Notify>>,
    __arg1: ClientIp,
    __arg2: State<State>,
    body: Args<Request>,
) -> Result<Response>
POST /_matrix/client/unstable/org.matrix.simplified_msc3575/sync (MSC4186)

A simplified version of sliding sync (MSC3575).

Get all new events in a sliding window of rooms since the last sync or a given point in time.