get_location_for_protocol_route

Function get_location_for_protocol_route 

pub(crate) async fn get_location_for_protocol_route(
    __arg0: State<State>,
    body: Args<Request>,
) -> Result<Response>
GET /_matrix/client/v3/thirdparty/location/{protocol}

Looks up third-party locations on a protocol via the registered appservices. Successful bridge responses retain appservice-id order and the order of the locations within each response.