sso_choices

Function sso_choices 

fn sso_choices(services: &Services) -> impl Iterator<Item = (&'_ str, &'_ str)>
Providers the login page offers, as the client login flows list them.

When single_sso or sso_custom_providers_page replaces that list, the page offers one single sign-on entry for the default provider instead.