authenticate

Function authenticate 

async fn authenticate<T>(
    request: Request,
    services: &State,
    json_body: Option<&CanonicalJsonValue>,
) -> Result<(Request, Auth)>
where T: IncomingRequest + Debug + Send + Sync + 'static, T::Authentication: AuthDispatch,
Authenticates a request while retaining the headers consumed by extraction.

The parsed canonical body remains available to federation authentication.