get_server_keys_deprecated_route

Function get_server_keys_deprecated_route 

pub(crate) async fn get_server_keys_deprecated_route(
    __arg0: State<State>,
) -> impl IntoResponse
GET /_matrix/key/v2/server/{keyId}

Gets the public signing keys of this server.

  • Matrix does not support invalidating public keys, so the key returned by this will be valid forever.