pub(crate) async fn get_server_keys_route(
__arg0: State<State>,
) -> Result<impl IntoResponse>Expand description
GET /_matrix/key/v2/server
Gets the public signing keys of this server.
- Matrix does not support invalidating public keys, so the key returned by this will be valid forever.