pub(crate) async fn request_3pid_management_token_via_msisdn_route(
_body: Args<Request>,
) -> Result<Response>Expand description
POST /_matrix/client/v3/account/3pid/msisdn/requestToken
“This API should be used to request validation tokens when adding an phone number to an account”
- 403 signals that The homeserver does not allow the third party identifier as a contact option.