fn notice_power_levels(server_user: &UserId) -> RoomPowerLevelsEventContentExpand description
Reserves posting and room administration for the server identity.
Recipients retain the ability to join and subsequently leave the room.
fn notice_power_levels(server_user: &UserId) -> RoomPowerLevelsEventContentReserves posting and room administration for the server identity.
Recipients retain the ability to join and subsequently leave the room.