pub(crate) async fn admin_set_room_block_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
PUT /_synapse/admin/v1/rooms/{room_id}/block
Blocks or unblocks a room, recording the requesting admin as the blocker. Pre-emptively blocking a room the server does not know is allowed.