pub(crate) async fn delete_alias_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
DELETE /_matrix/client/v3/directory/room/{roomAlias}
Deletes a room alias from this server.
The deleted alias is also stripped from the room’s canonical alias event on a best-effort basis. A sender without permission to send that state event still deletes the alias.