async fn user_can_publish_room(
services: &Services,
user_id: &UserId,
room_id: &RoomId,
) -> Result<bool>Expand description
Check whether the user can publish to the room directory via power levels of room history visibility event or room creator