pub(crate) async fn get_key_changes_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
POST /_matrix/client/r0/keys/changes
Gets a list of users who have updated their device identity keys since the previous sync token.
- TODO: left users