async fn merge_remote_master_key<F>(
services: &Services,
sender_user: Option<&UserId>,
allowed_signatures: &F,
user: &UserId,
master_key_raw: Raw<CrossSigningKey>,
) -> Result<Raw<CrossSigningKey>>Expand description
Merges signatures from our cached copy of the user’s master key (if any) onto the remote-supplied master key, persists the merged copy to our database, and returns the merged Raw value for the response.