pub(crate) async fn forget_room_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
POST /_matrix/client/v3/rooms/{roomId}/forget
Forgets about a room.
- If the sender user currently left the room: Stops sender user from receiving information about the room
Note: Other devices of the user have no way of knowing the room was forgotten, so this has to be called from every device