pub(crate) async fn join_room_by_id_route(
__arg0: State<State>,
__arg1: ClientIp,
body: Args<Request>,
) -> Result<Response>Expand description
POST /_matrix/client/r0/rooms/{roomId}/join
Tries to join the sender user into a room.
- If the server knowns about this room: creates the join event and does auth rules locally
- If the server does not know about the room: asks other servers over federation