pub(crate) async fn get_displayname_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
GET /_matrix/client/v3/profile/{userId}/displayname
Returns the displayname of the user.
- If user is on another server and we do not have a local copy already fetch displayname over federation