pub(crate) async fn get_profile_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
GET /_matrix/client/v3/profile/{userId}
Returns the displayname, avatar_url, blurhash, and tz of the user.
- If user is on another server and we do not have a local copy already, fetch profile over federation.