async fn is_event_report_valid(
services: &Services,
event_id: &EventId,
room_id: &RoomId,
sender_user: &UserId,
reason: Option<&String>,
pdu: &PduEvent,
) -> ResultExpand description
in the following order:
check if the room ID from the URI matches the PDU’s room ID check if report reasoning is less than or equal to 750 characters check if reporting user is in the reporting room