pub(crate) async fn get_state_events_for_key_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
GET /_matrix/client/v3/rooms/{roomid}/state/{eventType}/{stateKey}
Get single state event of a room with the specified state key.
The optional query parameter ?format=event|content allows returning the
full room state event or just the state event’s content (default behaviour)
- If not joined: Only works if current room history visibility is world readable