fn present_member<T>(event: &Raw<T>) -> Option<OwnedUserId>Expand description
The subject of a membership event that can introduce a profile base.
Current shared membership is checked before reading any candidate’s values. The state key is owned because a historical user ID may need JSON unescaping.