pub(crate) async fn get_protocol_route(
__arg0: State<State>,
body: Args<Request>,
) -> Result<Response>Expand description
GET /_matrix/client/v3/thirdparty/protocol/{protocol}
Fetches metadata from every appservice declaring the requested protocol.
The route returns M_NOT_FOUND when no registered bridge advertises it or
none of the declaring bridges returns a successfully decoded response.