pub(crate) async fn get_supported_versions_route(
_body: Args<Request>,
) -> Result<Response>Expand description
GET /_matrix/client/versions
Get the versions of the specification and unstable features supported by this server.
- Versions take the form MAJOR.MINOR.PATCH
- Only the latest PATCH release will be reported for each MAJOR.MINOR value
- Unstable features are namespaced and may include version information in their name
Note: Unstable features are used while developing new features. Clients should avoid using unstable features in their stable releases