fn needs_interstitial(redirect_url: &Url, native: bool) -> boolExpand description
Whether returning the authorization code requires a user gesture.
Private-use reverse-DNS schemes and native HTTPS universal links need a Continue link to open the application. Web HTTPS and native HTTP loopback callbacks use an automatic HTML handoff.