async fn authenticate<T>(
request: Request,
services: &State,
json_body: Option<&CanonicalJsonValue>,
) -> Result<(Request, Auth)>Expand description
Authenticates a request while retaining the headers consumed by extraction.
The parsed canonical body remains available to federation authentication.