async fn record_local_invite(
services: &Services,
body: &Args<Request>,
invited_user: &UserId,
sender: &UserId,
invite_state: Vec<Raw<AnyStrippedStateEvent>>,
pdu: &PduEvent,
) -> Result<()>Expand description
Record an invite for a room we are not currently in.
When we are active in the room, the remote server will notify us about the
join/invite through /send. When we are not in the room, the invited state
must be recorded manually for client /sync through update_membership(),
and the invite PDU pushed to the relevant appservices.